searchNodes=[{"doc":"Utilities for advent of code solution modules.This module contains a set of macros and helper functions which should be used to generate solution modules for advent of code. When solving the problem for &lt;day&gt; of &lt;year&gt;, this module can be imported, after which the aoc/3 macro can be used to automatically generate a solution module. The intended use looks like this:import AOC aoc 2020, 1 do def p1 do input_stream() |&gt; ... end def p2 do input_stream() |&gt; ... end endDefining a module with the aoc/3 macro has a few advantages:The input_path, input_string and input_stream functions are generated and inserted into the generated module.The p1/0, p1/1, p1/2, p2/0, p2/1 and p2/2 functions can be used to call the p1 and p2 functions in this module, making the development experience a bit nicer.Overall, the macros in these modules are intended to allow you to forego writing boilerplate code which is shared between all the solutions.aoc/3 and use AOCInternally, aoc/3 generates a module with a predefined name (Y&lt;year&gt;.D&lt;day&gt;) which contains a use AOC, day: &lt;day&gt;, year: &lt;year&gt; statement. In turn, the __using__/1 macro defined in this module is responsible for generating the input_* helper functions. Thus, if you prefer to use a different naming scheme than the one imposed by aoc/3, you can do something like the following:defmodule MySolution do use AOC, day: &lt;day&gt;, year: &lt;year&gt; ... endWhen using AOC like this, you cannot use the p* helper functions, but you get access to the various input_* functions.input_* functionsInside the generated module, the following functions are available:input_path/0: Get the path to the input for the module's day / year.input_string/0: Use File.read!/1 to read input_path/0.input_stream/0: Use File.stream!/1 to read input_path/0 and map String.trim/1 over the stream.Each of these functions is overridable. This makes it possible to add the example input to your module when testing your code, for instance, the following code can be used to use the example input for year 2020 day 1.aoc 2020, 1 do def input_stream do [ &quot;1721&quot;, &quot;979&quot;, &quot;366&quot;, &quot;299&quot;, &quot;675&quot;, &quot;1456&quot; ] end ... endBesides the input_* functions, the following two functions are available:_aoc_day/0: Get the day of the module_aoc_year/0: Get the year of the modulep1(), p2() and othersInside the body of aoc/3, it is intended that you define the solution to part 1 inside a p1 function and the solution to part 2 inside a p2 function. If you do this, the helpers defined in this module can be used to quickly call p1 or p2 for a given day and year from within iex.day and year can be passed as arguments, if they are not passed as arguments, the :advent_of_code application environment is checked for the value of :day or :year (using Application.get_env/3). If the value is present, it is used, otherwise, the current day or year is used. Since the application environment is used, you can override day or year in your config/config.exs file.If auto_reload? is set to true in the :advent_of_code_utils application configuration, running p1() or p2() will recompile the current mix project (with IEx.Helpers.recompile/1) before calling p1 or p2.","ref":"AOC.html","title":"AOC","type":"module"},{"doc":"The generated module will be named Y&lt;year&gt;.D&lt;day&gt;. use AOC will be injected in the body of the module, so that the input helpers described in AOC are available.Examplesimport AOC aoc 2020, 1 do def some_function do :foo end endis equivalent to:defmodule Y2020.D1 do use AOC def some_function do :foo end end","ref":"AOC.html#aoc/3","title":"AOC.aoc/3","type":"macro"},{"doc":"Call Y&lt;year&gt;.D&lt;day&gt;.p1()day and year are fetched from the :advent_of_code_utils application environment. The current day / year is used if these are not set.Recompiles the current mix project is auto_reload? is enabled.","ref":"AOC.html#p1/0","title":"AOC.p1/0","type":"function"},{"doc":"Call Y&lt;year&gt;.D&lt;day&gt;.p1()day is passed as a parameter, year is fetched from the :advent_of_code_utils application environment. If it is not set, the current year is used.Recompiles the current mix project is auto_reload? is enabled.","ref":"AOC.html#p1/1","title":"AOC.p1/1","type":"function"},{"doc":"Call Y&lt;year&gt;.D&lt;day&gt;.p1()Recompiles the current mix project is auto_reload? is enabled.","ref":"AOC.html#p1/2","title":"AOC.p1/2","type":"function"},{"doc":"Call Y&lt;year&gt;.D&lt;day&gt;.p2()day and year are fetched from the :advent_of_code_utils application environment. The current day / year is used if these are not set.Recompiles the current mix project is auto_reload? is enabled.","ref":"AOC.html#p2/0","title":"AOC.p2/0","type":"function"},{"doc":"Call Y&lt;year&gt;.D&lt;day&gt;.p2()day is passed as a parameter, year is fetched from the :advent_of_code_utils application environment. If it is not set, the current year is used.Recompiles the current mix project is auto_reload? is enabled.","ref":"AOC.html#p2/1","title":"AOC.p2/1","type":"function"},{"doc":"Call Y&lt;year&gt;.D&lt;day&gt;.p2()Recompiles the current mix project is auto_reload? is enabled.","ref":"AOC.html#p2/2","title":"AOC.p2/2","type":"function"},{"doc":"Fetch input and create a code skeleton for a given day / year.This mix task:Creates a code skeleton for the specified day / yearFetches the input of day / year and stores itPrints the url of today's challenge.If this task is run multiple times for the same day / year, the input is not fetched again (if it has not been deleted) and existing files are not overwritten.Session cookieIn order to fetch your input, this task needs your advent of code session cookie. This can be obtained by investigating your cookies after logging in on the advent of code website. The cookie can be stored inside your config/config.exs file (e.g. config, :advent_of_code_utils, :session, &quot;&lt;your cookie here&gt;&quot;) or it can be passed as a command-line argument. If no cookie is present, the input can not be fetched.Day and YearThe day and year can be passed as a command-line argument or be specified in the application configuration. If neither of these are present, today's date is used.File locationsBy default, this task stores the fetched inputs in input/&lt;year&gt;_&lt;day&gt;.txt. The code skeletons are stored in lib/&lt;year&gt;/&lt;day&gt;.ex. These values can be modified by setting the :input_path and :code_path values of the :advent_of_code_utils application. The provided path should be a string which may contain :year and :day. If these values are present, they will be replaced by the relevant day or year.For instance, the following code will store inputs in inputs/&lt;year&gt;/&lt;day&gt;.input:config :advent_of_code_utils, :input_path, &quot;inputs/:year/:day.input&quot;Command-line arguments-s or --session: Specify the session cookie.-y or --year: Specify the year.-d or --day: Specify the day.All of these options take precedence over their application environment counterparts.","ref":"Mix.Tasks.Aoc.html","title":"Mix.Tasks.Aoc","type":"task"},{"doc":"Callback implementation for Mix.Task.run/1.","ref":"Mix.Tasks.Aoc.html#run/1","title":"Mix.Tasks.Aoc.run/1","type":"function"},{"doc":"Advent of Code Utils Input fetching and boilerplate generation for Advent of Code.The goal of this project is to eliminate most of the manual labor involved with working on the yearly Advent of Code challenges.As a sample, this is the workflow you'd use when working on the challenge of the first of December 2020:$ mix aoc Creating code path: lib/2020/1.ex Fetching input... Stored input: input/2020_1.txt Today&#39;s challenge can be found at: https://adventofcode.com/2020/day/1Afterwards, lib/2020/1.ex will look as follows:import AOC aoc 2020, 1 do def p1 do end def p2 do end endIn this generated module, you access the contents of the fetched input by using input_path(), input_string() or input_stream(). While solving your challenge, you can use the AOC.p1() and AOC.p2() helpers in iex to quickly test your solution so far. These helpers can also be set up to automatically recompile your mix project.All of this is configurable so that you can adjust this project to fit your own workflow. Check out the docs for more information!","ref":"readme.html","title":"Advent of Code Utils","type":"extras"},{"doc":"Add advent_of_code_utils to your list of dependencies in mix.exs:def deps do [ {:advent_of_code_utils, &quot;~&gt; 0.1&quot;} ] endStore your session cookie in config/config.exs. You can find this by inspecting your cookies after logging in to the advent of code website.config :advent_of_code_utils, session: &quot;&lt;your cookie&gt;&quot;Use mix aoc to work on today's challenge. The day and year of a challenge can be passed in various ways, so this project is still highly useful when you're catching up on older challenges.Add import AOC to your iex.exs file. This allows you to use the utilities defined in AOC without specifying the module name. (optional)Set auto_reload? in your config/config.exs if you want the various AOC.p* to recompile your project (optional):config :advent_of_code_utils, auto_reload?: true","ref":"readme.html#installation-use","title":"Advent of Code Utils - Installation &amp; Use","type":"extras"},{"doc":"This project grew from a collection of utilities I wrote for myself when working on advent of code. I polished these utilities, but it is very likely that some bugs are still present. If you run into any issue, feel free to create an issue on GitHub.","ref":"readme.html#issues","title":"Advent of Code Utils - Issues","type":"extras"}]